/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  WLAN Signaling
 *  Original Release: March 2012
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/
#include "rscmwwls.h"

#pragma warning (disable:4055)

/*****************************************************************************
 * Function: rscmwwls_withReliability_ReadCallback
 * Purpose:  This function overrides standard calback funtion. Reads response, removes reliability.
             If Reliability==0, checks response else returns error.
 *****************************************************************************/
ViStatus rscmwwls_withReliability_ReadCallback(ViSession          instrSession,
                                               ViConstString      repCapName,
                                               RsCoreAttributePtr attr)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  reliability = 0;
    ViInt32  ivalue = 0;
    ViChar   *cmd = NULL,

           *value = NULL,
           *buffer = NULL;

    // Build the command string
    checkErr(RsCore_BuildAttrCommandString(instrSession, attr, repCapName, &cmd));

    // --- Attribute data type is used for VISA I/O ---
    switch (attr->dataType)
    {
    case RS_VAL_INT32:
        checkErr(RsCore_QueryAttributeCommandUnknownLength(instrSession, attr, cmd, &buffer, NULL));
        value = (ViChar*)malloc(strlen(buffer));
        (void)sscanf(buffer, "%ld,%s", &reliability, value);
        checkErr(rscmwwls_ReliabilityIndicator(instrSession, reliability, NULL));
        checkErr(RsCore_FindRangeTableDiscreteNumericValue(instrSession, attr->rangeTableDiscrete, value, &ivalue));
        checkErr(RsCore_SetAttributeP2Value(instrSession, attr, &ivalue));
        break;
    default:
        checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, NULL));
    }

Error:
    if (buffer)
        free(buffer);

    if (cmd)
        free(cmd);

    if (value)
        free(value);

    return error;
}

/*****************************************************************************
 * Function: rscmwwls_stringToHex_ReadCallback
 * Purpose:  Supported data types: RS_VAL_STRING
            Reads string response expected to be in the following format: "#H<string_value>,<bitLen>"
            Returns the <string_value> portion.
            Example: string response = '#HF0F0F0F0F0F0,48', returned value ='F0F0F0F0F0F0'
 *****************************************************************************/
ViStatus rscmwwls_stringToHex_ReadCallback(ViSession          instrSession,
                                           ViConstString      repCapName,
                                           RsCoreAttributePtr attr)
{
    return RsCore_SpecialCallback_BinOrHexPatternRead(instrSession, repCapName, attr);
}

/*****************************************************************************
 * Function: rscmwwls_stringToHex_WriteCallback
 * Purpose:  Supported data types: RS_VAL_STRING
             Writes string parameter in the following format: "#H<string_value>
             Example: value='F0F0F0F0F0F0', composed command: SOUR:BB:SIR:DATA:PATT #HF0F0F0F0F0F0
 *****************************************************************************/
ViStatus rscmwwls_stringToHex_WriteCallback(ViSession          instrSession,
                                            ViConstString      repCapName,
                                            RsCoreAttributePtr attr,
                                            void*              value)
{
    ViStatus error = VI_SUCCESS;

    if (attr->dataType != RS_VAL_STRING)
    {
        checkErr(RsCore_GenerateInvalidDataTypeError(instrSession, attr->dataType, "rscmwwls_stringToHex_WriteCallback only accepts RS_VAL_STRING data types"));
    }

    checkErr(RsCore_SpecialCallback_SurroundParamWrite(instrSession, repCapName, attr, " #H", value, NULL));

Error:
    return error;
}

/****************************************************************************************************
 *  rscmwwls_IntFormatStation_ReadCallback
 *  Data type: all
Replaces <station> with the Int32 value of the selectedStation attribute
******************************************************************************************************/
ViStatus rscmwwls_IntFormatStation_ReadCallback(ViSession          instrSession,
                                                ViConstString      repCapName,
                                                RsCoreAttributePtr attr,
                                                ViAttr             selectedStation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   customCmd[RS_MAX_MESSAGE_LEN];
    ViChar   aux[RS_MAX_SHORT_MESSAGE_BUF_SIZE];
    ViInt32  value;

    // If no command available, exit the function
    if (isNullOrEmpty(attr->command))
        goto Error;

    strncpy(customCmd, attr->command, RS_MAX_MESSAGE_LEN);

    // Replaces <station> with number
    if (selectedStation > 0)
    {
        checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, selectedStation, 0, &value));
        snprintf(aux, RS_MAX_SHORT_MESSAGE_BUF_SIZE, "%ld", value);
        RsCore_ReplaceString(customCmd, RS_MAX_MESSAGE_BUF_SIZE, "<station>", aux, VI_TRUE);
    }

    // Use the standard callback with this custom command
    checkErr(RsCore_SpecialCallback_CustomCommandRead(instrSession, repCapName, attr, customCmd));

Error:
    return error;
}

/****************************************************************************************************
 *  rscmwwls_IntFormatStation_WriteCallback
 *  Data type: All
Replaces <station> with the Int32 value of the selectedStation attribute
******************************************************************************************************/
ViStatus rscmwwls_IntFormatStation_WriteCallback(ViSession          instrSession,
                                                 ViConstString      repCapName,
                                                 RsCoreAttributePtr attr,
                                                 ViAttr             selectedStation,
                                                 void*              value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   customCmd[RS_MAX_MESSAGE_LEN];
    ViInt32  stationValue;
    ViChar   aux[RS_MAX_SHORT_MESSAGE_BUF_SIZE];

    // If no command is available, exit the function
    if (isNullOrEmpty(attr->command))
        goto Error;

    strncpy(customCmd, attr->command, RS_MAX_MESSAGE_LEN);

    // Replaces <station> with number
    if (selectedStation > 0)
    {
        checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, selectedStation, 0, &stationValue));
        snprintf(aux, RS_MAX_SHORT_MESSAGE_BUF_SIZE, "%ld", stationValue);
        RsCore_ReplaceString(customCmd, RS_MAX_MESSAGE_BUF_SIZE, "<station>", aux, VI_TRUE);
    }

    // Use the standard callback with this custom command
    checkErr(RsCore_SpecialCallback_CustomCommandWrite(instrSession, repCapName, attr, customCmd, value));

Error:
    return error;
}

/****************************************************************************************************
 *  rscmwwls_FormatAMPDUStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatAMPDUStationRepCapString_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatAMPDUStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatAMPDUStationRepCapString_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatDUTStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_DUT_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDUTStationRepCapString_ReadCallback(ViSession          instrSession,
                                                            ViConstString      repCapName,
                                                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DUT_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatDUTStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDUTStationRepCapString_WriteCallback(ViSession          instrSession,
                                                             ViConstString      repCapName,
                                                             RsCoreAttributePtr attr,
                                                             void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DUT_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatDataFrameStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDataFrameStationRepCapString_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatDataFrameStationRepCapInt32_ReadCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with the int32 value of RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDataFrameStationRepCapInt32_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatDataFrameStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDataFrameStationRepCapString_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatDataFrameStationRepCapInt32_WriteCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with value of RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatDataFrameStationRepCapInt32_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatHETBStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_HE_TB_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatHETBStationRepCapString_ReadCallback(ViSession          instrSession,
                                                             ViConstString      repCapName,
                                                             RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_HE_TB_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatHETBStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_HE_TB_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatHETBStationRepCapString_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_HE_TB_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatIP4StationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_IPV4_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatIP4StationRepCapString_ReadCallback(ViSession          instrSession,
                                                            ViConstString      repCapName,
                                                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_IPV4_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatIP4StationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_IPV4_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatIP4StationRepCapString_WriteCallback(ViSession          instrSession,
                                                             ViConstString      repCapName,
                                                             RsCoreAttributePtr attr,
                                                             void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_IPV4_SELECTED_STATION, value);
}






/****************************************************************************************************
 *  rscmwwls_FormatQOSTIDStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatQOSTIDStationRepCapString_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatQOSTIDStationRepCapInt32_ReadCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with the int32 value of RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatQOSTIDStationRepCapInt32_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatQOSTIDStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatQOSTIDStationRepCapString_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatQOSTIDStationRepCapInt32_WriteCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with value of RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatQOSTIDStationRepCapInt32_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatSignalingStationRepCapString_WriteCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with value of RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatSignalingStationRepCapString_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatSignalingStationRepCapInt32_WriteCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with value of RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatSignalingStationRepCapInt32_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatSignalingStationRepCapNone_WriteCallback
 *  Data type: RS_VAL_NONE
Replaces <station> with value of RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatSignalingStationRepCapNone_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapBool_ReadCallback
 *  Data type: RS_VAL_BOOLEAN
Replaces <station> with the int32 value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapBool_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapInt32_ReadCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with the int32 value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapInt32_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapReal64_ReadCallback
 *  Data type: RS_VAL_REAL64
Replaces <station> with the int32 value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapReal64_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapBool_WriteCallback
 *  Data type: RS_VAL_BOOLEAN
Replaces <station> with value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapBool_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapInt32_WriteCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapInt32_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION, value);
}

/****************************************************************************************************
 *  rscmwwls_FormatTriggerFrameStationRepCapReal64_WriteCallback
 *  Data type: RS_VAL_REAL64
Replaces <station> with value of RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatTriggerFrameStationRepCapReal64_WriteCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr,
                            void*              value)
{
    return rscmwwls_IntFormatStation_WriteCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION, value);
}



/****************************************************************************************************
 *  rscmwwls_FormatUECapabilityStationRepCapString_ReadCallback
 *  Data type: RS_VAL_STRING
Replaces <station> with the int32 value of RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatUECapabilityStationRepCapString_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatUECapabilityStationRepCapInt32_ReadCallback
 *  Data type: RS_VAL_INT32
Replaces <station> with the int32 value of RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatUECapabilityStationRepCapInt32_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION);
}

/****************************************************************************************************
 *  rscmwwls_FormatUECapabilityStationRepCapReal64_ReadCallback
 *  Data type: RS_VAL_REAL64
Replaces <station> with the int32 value of RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION
******************************************************************************************************/
ViStatus rscmwwls_FormatUECapabilityStationRepCapReal64_ReadCallback(
                            ViSession          instrSession,
                            ViConstString      repCapName,
                            RsCoreAttributePtr attr)
{
    return rscmwwls_IntFormatStation_ReadCallback(instrSession, repCapName, attr, RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION);
}
